@@ -179,7 +179,7 @@ class LambdaToSsmstringparameter(
             vpc_props=vpc_props,
         )
 
-        jsii.create(LambdaToSsmstringparameter, self, [scope, id, props])
+        jsii.create(self.__class__, self, [scope, id, props])
 
     @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="lambdaFunction")
